import { JsonRpcProvider } from '@pokt-foundation/pocketjs-provider';
import { AbstractSigner, KeyManager } from '@pokt-foundation/pocketjs-signer';
import { HTTPMethod, Node, PocketAAT, RelayHeaders, Session } from '@pokt-foundation/pocketjs-types';
import { AbstractRelayer } from './abstract-relayer';
export declare class Relayer implements AbstractRelayer {
    readonly keyManager: KeyManager;
    readonly provider: JsonRpcProvider;
    readonly dispatchers: string[];
    private secureEnsured;
    constructor({ keyManager, provider, dispatchers }: {
        keyManager: any;
        provider: any;
        dispatchers: any;
    });
    /**
     * Performs a dispatch request to obtain a new session. Fails if no dispatcher is provided through the provider.
     * @param {string} applicationPubKey - The application's public key.
     * @param {string} chain - The chain for the session.
     * @param {string} sessionBlockHeight - The session block height. Defaults to 0, as usually you'd want the latest session.
     * @param {object} options - The options available to tweak the request itself.
     * @param {number} options.retryAttempts - The number of retries to perform if the first call fails.
     * @param {boolean} options.rejectSelfSignedCertificates - Option to reject self signed certificates or not.
     * @param {timeout} options.timeout - Timeout before the call fails. In milliseconds.
     * @returns {DispatchResponse} - The dispatch response from the dispatcher node, as a session.
     * */
    getNewSession({ applicationPubKey, chain, sessionBlockHeight, options, }: {
        applicationPubKey?: string;
        chain: string;
        sessionBlockHeight?: number;
        options?: {
            retryAttempts?: number;
            rejectSelfSignedCertificates?: boolean;
            timeout?: number;
        };
    }): Promise<Session>;
    static relay({ blockchain, data, headers, keyManager, method, node, path, pocketAAT, provider, session, options, }: {
        blockchain: string;
        data: string;
        headers?: RelayHeaders | null;
        keyManager: KeyManager | AbstractSigner;
        method: HTTPMethod | '';
        node: Node;
        path: string;
        pocketAAT: PocketAAT;
        provider: JsonRpcProvider;
        session: Session;
        options?: {
            retryAttempts?: number;
            rejectSelfSignedCertificates?: boolean;
            timeout?: number;
        };
    }): Promise<{
        response: any;
        relayProof: {
            entropy: number;
            sessionBlockheight: number;
            servicerPubKey: string;
            blockchain: string;
            aat: {
                version: string;
                appPubKey: string;
                clientPubKey: string;
                signature: string;
            };
            signature: string;
            requestHash: string;
        };
        serviceNode: Node;
    }>;
    /**
     * Sends a relay to the network.
     * @param {string} blockchain - The chain for the session.
     * @param {string} data - The data to send, stringified.
     * @param {object} headers - The headers to include in the call, if any.
     * @param {Node} node - The node to send the relay to. The node must belong to the current session.
     * @param {string} path - The path to query in the relay e.g "/v1/query/node". Useful for chains like AVAX.
     * @param {AAT} pocketAAT - The pocket AAT used to authenticate the relay.
     * @param {Session} session - The current session the app is assigned to.
     * @param {object} options - The options available to tweak the request itself.
     * @param {number} options.retryAttempts - The number of retries to perform if the first call fails.
     * @param {boolean} options.rejectSelfSignedCertificates - Option to reject self signed certificates or not.
     * @param {timeout} options.timeout - Timeout before the call fails. In milliseconds.
     * @returns {RelayResponse} - The relay response.
     * */
    relay({ blockchain, data, headers, method, node, path, pocketAAT, session, options, }: {
        data: string;
        blockchain: string;
        pocketAAT: PocketAAT;
        headers?: RelayHeaders | null;
        method: HTTPMethod | '';
        session: Session;
        node: Node;
        path: string;
        options?: {
            retryAttempts?: number;
            rejectSelfSignedCertificates?: boolean;
            timeout?: number;
        };
    }): Promise<{
        response: any;
        relayProof: {
            entropy: number;
            sessionBlockheight: number;
            servicerPubKey: string;
            blockchain: string;
            aat: {
                version: string;
                appPubKey: string;
                clientPubKey: string;
                signature: string;
            };
            signature: string;
            requestHash: string;
        };
        serviceNode: Node;
    }>;
    static getRandomSessionNode(session: Session): Node;
    static isNodeInSession(session: Session, node: Node): boolean;
    static generateProofBytes({ entropy, sessionBlockHeight, servicerPublicKey, blockchain, pocketAAT, requestHash, }: {
        entropy: bigint | string | number;
        sessionBlockHeight: string | number;
        servicerPublicKey: string;
        blockchain: string;
        pocketAAT: PocketAAT;
        requestHash: any;
    }): string;
    static hashAAT(aat: PocketAAT): string;
    static hashRequest(requestHash: any): string;
    static getRandomIntInclusive(min?: number, max?: number): number;
}
//# sourceMappingURL=relayer.d.ts.map